| pp_check.mvgam | R Documentation |
mvgam modelsPerform unconditional posterior predictive checks with the help of the bayesplot package.
## S3 method for class 'mvgam'
pp_check(
object,
type,
ndraws = NULL,
prefix = c("ppc", "ppd"),
group = NULL,
x = NULL,
newdata = NULL,
...
)
object |
An object of class |
type |
Type of the ppc plot as given by a character string.
See |
ndraws |
Positive integer indicating how many
posterior draws should be used.
If |
prefix |
The prefix of the bayesplot function to be applied. Either '"ppc"' (posterior predictive check; the default) or '"ppd"' (posterior predictive distribution), the latter being the same as the former except that the observed data is not shown for '"ppd"'. |
group |
Optional name of a factor variable in the model
by which to stratify the ppc plot. This argument is required for
ppc |
x |
Optional name of a variable in the model.
Only used for ppc types having an |
newdata |
Optional |
... |
Further arguments passed to |
Unlike the conditional posterior checks provided by ppc,
This function computes unconditional posterior predictive checks (i.e. it generates
predictions for fake data without considering the true observations associated with those
fake data). For a detailed explanation of each of the ppc functions,
see the PPC
documentation of the bayesplot
package.
A ggplot object that can be further customized using the ggplot2 package.
Nicholas J Clark
ppc, predict.mvgam
## Not run:
simdat <- sim_mvgam(seasonality = "hierarchical")
mod <- mvgam(
y ~ series +
s(season, bs = "cc", k = 6) +
s(season, series, bs = "fs", k = 4),
data = simdat$data_train,
chains = 2,
silent = 2
)
# Use pp_check(mod, type = "xyz") for a list of available plot types
# Default is a density overlay for all observations
pp_check(mod)
# Rootograms particularly useful for count data
pp_check(mod, type = "rootogram")
# Grouping plots by series is useful
pp_check(mod,
type = "bars_grouped",
group = "series", ndraws = 50
)
pp_check(mod,
type = "ecdf_overlay_grouped",
group = "series", ndraws = 50
)
pp_check(mod,
type = "stat_freqpoly_grouped",
group = "series", ndraws = 50
)
# Several types can be used to plot distributions of randomized
# quantile residuals
pp_check(
object = mod,
x = "season",
type = "resid_ribbon"
)
pp_check(
object = mod,
x = "season",
group = "series",
type = "resid_ribbon_grouped"
)
pp_check(mod,
ndraws = 5,
type = "resid_hist_grouped",
group = "series"
)
# Custom functions accepted
pp_check(mod, type = "stat", stat = function(x) mean(x == 0))
pp_check(mod,
type = "stat_grouped",
stat = function(x) mean(x == 0),
group = "series"
)
# Some functions accept covariates to set the x-axes
pp_check(mod,
x = "season",
type = "ribbon_grouped",
prob = 0.5,
prob_outer = 0.8,
group = "series"
)
# Many plots can be made without the observed data
pp_check(mod, prefix = "ppd")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.