- object
list object returned from mvgam. See mvgam()
- ...
further par graphical parameters.
- newdata
Optional dataframe or list of test data containing at least 'series' and 'time'
for the forecast horizon, in addition to any other variables included in the linear predictor of formula. If
included, the observed values in the test data are compared to the model's forecast distribution for exploring
biases in model predictions.
Note this is only useful if the same newdata was also included when fitting the original model.
- data_test
Deprecated. Still works in place of newdata but users are recommended to use
newdata instead for more seamless integration into R workflows
- series
integer specifying which series in the set is to be plotted
- type
character specifying the type of posterior predictive check to calculate and plot.
Valid options are: 'rootogram', 'mean', 'hist', 'density', 'prop_zero', 'pit' and 'cdf'
- n_bins
integer specifying the number of bins to use for binning observed values when plotting
a rootogram or histogram. Default is 50 bins for a rootogram, which means that if
there are >50 unique observed values, bins will
be used to prevent overplotting and facilitate interpretation. Default for a histogram is to use the
number of bins returned by a call to hist in base R
- legend_position
The location may also be specified by setting x to a single keyword from the
list "bottomright", "bottom", "bottomleft", "left", "topleft", "top", "topright", "right" and "center".
This places the legend on the inside of the plot frame at the given location. Or alternatively,
use "none" to hide the legend.
- xlab
label for x axis.
- ylab
label for y axis.